@@ -31,7 +31,7 @@ ScheduleEditor::ScheduleEditor(QWidget *parent)
     QVBoxLayout *layout = new QVBoxLayout(this);
     view = new WeekView(this);
     layout->addWidget(view);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
 
     setupActions();
